==> libcprime-2.7.0.tar.gz: libcprime-v2.7.0/cprime/settingsmanage.cpp <==
/*
    *
    * This file is a part of Libcprime.
    * Library for bookmarking, saving recent activites, managing settings for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QDir>
#include <QFontDatabase>
#include <QIcon>
#include <QFileInfo>
#include <QProcess>
#include <QStandardPaths>

#include "cvariables.h"
#include "settingsmanage.h"

QSettings* settingsManage::cSetting = nullptr;
settingsManage *settingsManage::mSettingsManage = nullptr;

settingsManage::settingsManage(bool checkIndividual)
{
    cSetting = new QSettings("coreapps", "coreapps");
    qDebug() << "Settings file " << cSetting->fileName();

    QString defaultSett = CPrime::Variables::CC_CoreApps_Default_ConfigFilePath();
    QString userSett = cSetting->fileName();
    if (!QFileInfo(cSetting->fileName()).exists()) {
        qDebug() << "Creating settings path : " << QDir().mkpath(QFileInfo(userSett).absolutePath());
        qDebug() << "Default settings path : " << defaultSett;
        qDebug() << "User settings path : " << userSett;
        qDebug() << "Copying default Settings : " << QFile(defaultSett).copy(userSett);

        // Save user home directory
        if (!cSetting->value("CoreFM/StartupPath").toString().count()) {
            cSetting->setValue("CoreFM/StartupPath", QDir::homePath());
        }

        // Save screenshot directory
        if (!cSetting->value("CoreShot/SaveLocation").toString().count()) {
            cSetting->setValue("CoreShot/SaveLocation", QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
        }
    } else {
        if (checkIndividual) {
            QSettings defSett(defaultSett, QSettings::NativeFormat);

            foreach (QString key, defSett.allKeys()) {
                if (!cSetting->allKeys().contains(key)) {
                    cSetting->setValue(key, defSett.value(key));
                }
            }

            foreach (QString key, cSetting->allKeys()) {
                if (!defSett.allKeys().contains(key)) {
                    cSetting->remove(key);
                }
            }
        }
    }
}

settingsManage *settingsManage::initialize(bool checkIndividual)
{
    if (mSettingsManage) {
        return mSettingsManage;
    }

    mSettingsManage = new settingsManage(checkIndividual);
    return mSettingsManage;
}

void settingsManage::reload()
{
    cSetting->sync();
}

QStringList settingsManage::getKeys(const QString &appName)
{
    cSetting->beginGroup(appName);
    QStringList keys = cSetting->childKeys();
    cSetting->endGroup();
    return keys;
}

settingsManage::cProxy settingsManage::value(const QString &appName, const QString &key, QVariant defaultValue)
{
    cSetting->sync();		//Better than calling reload()

    if ( ( appName == "CoreApps" ) and ( key == "TouchMode" ) ) {
		int touch = cSetting->value( appName + "/" + key ).toInt();
		switch ( touch ) {
			/* Auto detect */
			case 0: {
				QProcess proc;
				proc.start( "udevadm", QStringList() << "info" << "--export-db" );
				proc.waitForFinished( -1 );

				QString output = QString::fromLocal8Bit( proc.readAllStandardOutput() + '\n' + proc.readAllStandardError() );
				if ( output.contains( "ID_INPUT_TOUCHSCREEN=1" ) )
					return cProxy{ "Dummy", true };

				return cProxy{ "Dummy", false };
			}

			/* TouchMode is on */
			case 1:
				return cProxy{ "Dummy", true };

			/* TouchMode is off */
			case 2:
				return cProxy{ "Dummy", false };

			default:
				return cProxy{ "Dummy", false };
        }
	}

	else if ( ( appName == "CoreApps" ) and ( key == "TouchModeRaw" ) ) {
		return cProxy{ "Dummy", cSetting->value( appName + "/TouchMode" ).toInt() };
	}

    return cProxy{ appName + "/" + key, defaultValue };
}

void settingsManage::setValue(const QString &appName, const QString &key, QVariant value)
{
    cSetting->setValue(appName + "/" + key, value);
}

==> libcprime-2.8.0.tar.gz: libcprime-v2.8.0/cprime/settingsmanage.cpp <==
/*
    *
    * This file is a part of Libcprime.
    * Library for bookmarking, saving recent activites, managing settings for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QDir>
#include <QFontDatabase>
#include <QIcon>
#include <QFileInfo>
#include <QProcess>
#include <QStandardPaths>

#include "cvariables.h"
#include "settingsmanage.h"


QSettings* settingsManage::cSetting = nullptr;
settingsManage *settingsManage::mSettingsManage = nullptr;

settingsManage::settingsManage(bool checkIndividual)
{
    cSetting = new QSettings("coreapps", "coreapps");
    qDebug() << "Settings file " << cSetting->fileName();

    QString defaultSett = CPrime::Variables::CC_CoreApps_Default_ConfigFilePath();
    QString userSett = cSetting->fileName();
    if (!QFileInfo(cSetting->fileName()).exists()) {
        qDebug() << "Creating settings path : " << QDir().mkpath(QFileInfo(userSett).absolutePath());
        qDebug() << "Default settings path : " << defaultSett;
        qDebug() << "User settings path : " << userSett;
        qDebug() << "Copying default Settings : " << QFile(defaultSett).copy(userSett);

        // Save user home directory
        if (!cSetting->value("CoreFM/StartupPath").toString().count()) {
            cSetting->setValue("CoreFM/StartupPath", QDir::homePath());
        }

        // Save screenshot directory
        if (!cSetting->value("CoreShot/SaveLocation").toString().count()) {
            cSetting->setValue("CoreShot/SaveLocation", QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
        }

        // As default settings not exist we should contain to set value for default
        // Add system font to CorePad, CoreTerminal, CoreKeyboard
        QFont font = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
        if (!font.family().count()) {
            font = QFont("Cantarell", 9);
        }

        cSetting->setValue("CorePad/Font", font);
        cSetting->setValue("CoreTerminal/Font", font);
        cSetting->setValue("CoreKeyboard/Font", font.family());

        // Set keyboard layout to mobile and mode to fixed while touch mode detected
        bool touch = value("CoreApps", "TouchMode");
        if (touch) {
            setValue("CoreKeyboard", "Layout", 0);
            setValue("CoreKeyboard", "Mode", 0);
        } else {
            setValue("CoreKeyboard", "Layout", 1);
            setValue("CoreKeyboard", "Mode", 1);
        }
    } else {
        if (checkIndividual) {
            QSettings defSett(defaultSett, QSettings::NativeFormat);

            Q_FOREACH (QString key, defSett.allKeys()) {
                if (!cSetting->allKeys().contains(key)) {
                    cSetting->setValue(key, defSett.value(key));
                }
            }

            Q_FOREACH (QString key, cSetting->allKeys()) {
                if (!defSett.allKeys().contains(key)) {
                    cSetting->remove(key);
                }
            }
        }
    }
}

settingsManage *settingsManage::initialize(bool checkIndividual)
{
    if (mSettingsManage) {
        return mSettingsManage;
    }

    mSettingsManage = new settingsManage(checkIndividual);
    return mSettingsManage;
}

void settingsManage::reload()
{
    cSetting->sync();
}

QStringList settingsManage::getKeys(const QString &appName)
{
    cSetting->beginGroup(appName);
    QStringList keys = cSetting->childKeys();
    cSetting->endGroup();
    return keys;
}

settingsManage::cProxy settingsManage::value(const QString &appName, const QString &key, QVariant defaultValue)
{
    cSetting->sync();		//Better than calling reload()

    if ( ( appName == "CoreApps" ) and ( key == "TouchMode" ) ) {
		int touch = cSetting->value( appName + "/" + key ).toInt();
		switch ( touch ) {
			/* Auto detect */
			case 0: {
				QProcess proc;
				proc.start( "udevadm", QStringList() << "info" << "--export-db" );
				proc.waitForFinished( -1 );

				QString output = QString::fromLocal8Bit( proc.readAllStandardOutput() + '\n' + proc.readAllStandardError() );
				if ( output.contains( "ID_INPUT_TOUCHSCREEN=1" ) )
					return cProxy{ "Dummy", true };

				return cProxy{ "Dummy", false };
			}

			/* TouchMode is on */
			case 1:
				return cProxy{ "Dummy", true };

			/* TouchMode is off */
			case 2:
				return cProxy{ "Dummy", false };

			default:
				return cProxy{ "Dummy", false };
        }
	}

	else if ( ( appName == "CoreApps" ) and ( key == "TouchModeRaw" ) ) {
		return cProxy{ "Dummy", cSetting->value( appName + "/TouchMode" ).toInt() };
	}

    return cProxy{ appName + "/" + key, defaultValue };
}

void settingsManage::setValue(const QString &appName, const QString &key, QVariant value)
{
    cSetting->setValue(appName + "/" + key, value);
}
